{ config,
  pkgs,
  ... }:

let
  gitpkgs = import <gitpkgs> {};
in
{
  nixpkgs.config = {
    allowBroken = false;

    packageOverrides = pkgs: rec {
      # Version override example:
      # rustracerd = pkgs.lib.overrideDerivation pkgs.rustracerd (attrs: rec {
      #   version = "2016-08-23";
      #   name = "racerd-${version}";
      #   src = pkgs.fetchgit {
      #     url = "git://github.com/jwilm/racerd.git";
      #     rev = "813d8214f50e8f77b5d8adf5173173209c8f6d74";
      #     sha256 = "07p4kvrc529khb1afrgwfkdb9nh3nvsk1v2p2b1rdaqvkpgwqr74";
      #   };
      # });

      go = pkgs.go_1_6;
      bluez = pkgs.bluez5;

      myLinuxPackages = pkgs.recurseIntoAttrs (pkgs.linuxPackagesFor
        (pkgs.linux_latest.override {
        kernelPatches = pkgs.linux_latest.kernelPatches ++ [
          {
            name = "bfq1";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0001-block-cgroups-kconfig-build-bits-for-BFQ-v7r11-4.5.0.patch";
              sha256 = "1j6h831kj32c9slzm4vhjvd8m17gbwh713kcpc54z9i02fwyq6ax";
            };
          }
          {
            name = "bfq2";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0002-block-introduce-the-BFQ-v7r11-I-O-sched-for-4.5.0.patch";
              sha256 = "1q8nf7fcp72s2xz2pfl22sv4w5fm4hzgciljrkd3g7gj5xvi27lw";
            };
          }
          {
            name = "bfq3";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0003-block-bfq-add-Early-Queue-Merge-EQM-to-BFQ-v7r11-for.patch";
              sha256 = "1q2j7g3cfwi52psxgwa06hadl6c2fh87ckm07pyaj35n6524gjg0";
            };
          }
        ];
        extraConfig  = ''
          BFQ_GROUP_IOSCHED y
          IOSCHED_BFQ y
          DEFAULT_BFQ y
        '';
        })
        pkgs.linuxPackages_latest
      );
      libvirt = pkgs.libvirt.override {
        xen = null;
      };
      libvirt-glib = pkgs.libvirt-glib.override {
        xen = null;
      };

    };

    allowUnfree = true;

    chromium = {
      enablePepperFlash = true;
      enablePepperPDF = true;
    };

    firefox = {
      enableGoogleTalkPlugin = true;
      enableAdobeFlash = false;
    };

    pidgin = {
      openssl = true;
      gnutls = true;
    };

    keepass = pkgs.keepass.override {
      plugins = [ pkgs.keepass-keefox ];
    };

  };

  imports =
    [
      ../common/pkg/default.nix
      ../common/pkg/neovim.nix
    ];

  environment.systemPackages = with pkgs; [
    androidsdk_4_4

    nixops
    nox
    ansible

    gnupg
    picocom
    roxterm
    xorg.xbacklight
    coreutils
    lsof

    xscreensaver
    chromium
    firefox-wrapper
    seafile-client

    qpdfview
    thunderbird
    keepass

    pidgin
    hexchat
    skype

    teamviewer
    x11_ssh_askpass
    gnome3.dconf # needed by virtmanager
    virtmanager
    qemu
    vagrant

    vlc
    audacity
    pavucontrol

    gimp
    inkscape
    pdftk
    imagemagick

    iptables
    nftables
    iperf

    #pandoc
    pythonFull

    gitpkgs.rkt
    gitpkgs.flannel
    gitpkgs.remmina
    gitpkgs.spotify
    gitpkgs.manuskript
#    gitpkgs.zoom-us
  ];
}
